@@ -9,12 +9,6 @@ from celery.log import setup_logger
 from celery import messaging
 
 
-def get_string_io_logger():
-    sio = StringIO()
-    logger = setup_logger(loglevel=logging.INFO, logfile=sio)
-    return logger, sio
-
-
 # Task run functions can't be closures/lambdas, as they're pickled.
 def return_True(self, **kwargs):
     return True
@@ -47,10 +41,11 @@ class TestCeleryTasks(unittest.TestCase):
             **kwargs):
         next_task = consumer.fetch()
         task_data = consumer.decoder(next_task.body)
-        self.assertEquals(task_data["celeryID"], task_id)
-        self.assertEquals(task_data["celeryTASK"], task_name)
+        self.assertEquals(task_data["id"], task_id)
+        self.assertEquals(task_data["task"], task_name)
+        task_kwargs = task_data.get("kwargs", {})
         for arg_name, arg_value in kwargs.items():
-            self.assertEquals(task_data.get(arg_name), arg_value)
+            self.assertEquals(task_kwargs.get(arg_name), arg_value)
 
     def test_raising_task(self):
         rtask = self.createTaskCls("RaisingTask", "c.unittest.t.rtask")
@@ -83,6 +78,7 @@ class TestCeleryTasks(unittest.TestCase):
         registry.tasks.register(T1)
         t1 = T1()
         consumer = t1.get_consumer()
+        self.assertRaises(NotImplementedError, consumer.receive, "foo", "foo")
         consumer.discard_all()
         self.assertTrue(consumer.fetch() is None)
 
@@ -141,8 +137,9 @@ class TestTaskSet(unittest.TestCase):
         consumer = IncrementCounterTask().get_consumer()
         for subtask_id in subtask_ids:
             m = consumer.decoder(consumer.fetch().body)
-            self.assertEquals(m.get("celeryTASKSET"), taskset_id)
-            self.assertEquals(m.get("celeryTASK"), IncrementCounterTask.name)
-            self.assertEquals(m.get("celeryID"), subtask_id)
-            IncrementCounterTask().run(increment_by=m.get("increment_by"))
+            self.assertEquals(m.get("taskset"), taskset_id)
+            self.assertEquals(m.get("task"), IncrementCounterTask.name)
+            self.assertEquals(m.get("id"), subtask_id)
+            IncrementCounterTask().run(
+                    increment_by=m.get("kwargs", {}).get("increment_by"))
         self.assertEquals(IncrementCounterTask.count, sum(xrange(1, 10)))
